/* Clique Enumeration 
 * Data intensive, memory intensive, computation intensive
 * This is the header file for clique enumeration.
 *
 * Author: Hoony Park
 * Date: 
 *
 * Copyright 2006-2007
 * Computer Science and Mathematics Division, Oak Ridge National Laboratory
 */

#ifndef _CLIQUE_H
#define _CLIQUE_H

#include <stdio.h>
#include "graph.h"
#include "mm.h"

/* #define USE_MPI */
/* #define USE_PTHREADS */

/* Global data. */
typedef struct {
    unsigned int InitCliqueSize;	/* lower bound of maximal clique size */
    unsigned int EndCliqueSize;		/* upper bound of maximal clique size */
    FILE **CliqueFP;			/* output cliques */  
} Configure;


extern Configure CG;
extern Graph *G;
extern MCB *mcb_list;			/* per-thread memory control block */
extern int num_threads;			/* number of threads per process */
extern int OUTPUT_SET;
extern int dynamic_load_balancing;
extern int full_statistics;		/* print per-thread statistics */


/* Randomize a list of integers. */
void shuffle(int *list, int n);

/* enumerate maximal cliques for a given graph */
void *clique_enumerate(void *id);

void init_graph();
void generate_root();
void init_memory();

#endif  /* _CLIQUE_H */
