#ifndef MM_H
#define MM_H

#if defined(USE_PTHREADS)
#include <pthread.h>
#endif

/* Enumeration type for vertices. */
typedef unsigned int	clist_t;

/* A working list of cliques of size clique_size. */
typedef struct {
  clist_t clique_size;
  clist_t k_1;
  clist_t ne;
  clist_t ce;
  clist_t list[];
} cstruct_t;

#define BLOCK_SIZE 100000  /* used to allocate a chunk of memory */

typedef struct MemoryBlock{
  struct MemoryBlock *_next;
  struct MemoryBlock *_prev;
  unsigned int _head;
  unsigned int _sp;
  clist_t *memory;
} MB;

typedef struct MemoryControlBlock {
    unsigned long clists;
#if defined(USE_PTHREADS)
    pthread_mutex_t mutex;
#endif
    unsigned long memory_level;
    unsigned long max_memory;
    clist_t *compsub;
    MB *BHead;
    MB *BTail;
} MCB;


void     MCB_initialize(MCB *CB, int node_count);
void     MCB_expand(MCB *CB);
clist_t *MCB_next(MCB *CB, int size);
void     MCB_advance(MCB *CB, int size);
int      MCB_retrieve(MCB *CB, clist_t *L);
int      MCB_dequeue(MCB *CB, clist_t *block, clist_t *compsub);

#endif
